@@ -113,7 +113,7 @@ sub _read {
     return if $! ~~ [EAGAIN, EINTR, EWOULDBLOCK];
 
     # Closed
-    return $self->close if $! == ECONNRESET;
+    return $self->close if $! ~~ [ECONNRESET, EPIPE];
 
     # Read error
     return $self->emit_safe(error => $!)->close;
